"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const main_1 = require("../main");
const http_1 = require("../util/http");
const appDirectoryHost = process.env.appDirectoryHost || 'https://app-directory.openfin.co';
exports.lookupServiceUrl = async (serviceName) => {
    if (appDirectoryHost.length > 0) {
        const appUrl = `${appDirectoryHost}/api/v1/apps/${serviceName}`;
        const mani = await http_1.fetchJson(appUrl);
        return mani.manifest_url;
    }
    console.error(`error getting startup url for ${serviceName}, host: ${appDirectoryHost}`);
    return '';
};
exports.launchService = async (service) => {
    let sURL = '';
    if (service.manifestUrl) {
        sURL = service.manifestUrl;
    }
    else {
        sURL = await exports.lookupServiceUrl(service.name);
    }
    await main_1.launch({ manifestUrl: sURL });
};
exports.startServices = async (services) => {
    for (let i = 0; i < services.length; i += 1) {
        const service = services[i];
        try {
            await exports.launchService(service);
        }
        catch (e) {
            console.error(e);
        }
    }
};
//# sourceMappingURL=services.js.map