import { Base } from '../base';
import { WriteRequestType, WriteAnyRequestType } from './write-request';
/**
 * WriteRequestType interface
 * @typedef { object } WriteRequestType
 * @property { string } name The name of the running application
 * @property { string } uuid The uuid of the running application
 */
/**
 * The Clipboard API allows reading and writing to the clipboard in multiple formats.
 * @namespace
*/
export default class Clipboard extends Base {
    /**
     * Writes data into the clipboard as plain text
     * @param { WriteRequestType } writeObj This object is described in the WriteRequestType typeof
     * @return {Promise.<void>}
     * @tutorial Clipboard.writeText
    */
    writeText(writeObj: WriteRequestType): Promise<void>;
    /**
     * Read the content of the clipboard as plain text
     * @param { string } type Clipboard Type
     * @return {Promise.<string>}
     * @tutorial Clipboard.readText
    */
    readText(type?: string): Promise<string>;
    /**
     * Writes data into the clipboard as Html
     * @param { WriteRequestType } writeObj This object is described in the WriteRequestType typedef
     * @return {Promise.<void>}
     * @tutorial Clipboard.writeHtml
    */
    writeHtml(writeObj: WriteRequestType): Promise<void>;
    /**
     * Read the content of the clipboard as Html
     * @param { string } type Clipboard Type
     * @return {Promise.<string>}
     * @tutorial Clipboard.readHtml
    */
    readHtml(type?: string): Promise<string>;
    /**
     * Writes data into the clipboard as Rtf
     * @param { WriteRequestType } writeObj This object is described in the WriteRequestType typedef
     * @return {Promise.<void>}
     * @tutorial Clipboard.writeRtf
    */
    writeRtf(writeObj: WriteRequestType): Promise<void>;
    /**
     * Read the content of the clipboard as Rtf
     * @param { string } type Clipboard Type
     * @return {Promise.<string>}
     * @tutorial Clipboard.readRtf
    */
    readRtf(type?: string): Promise<string>;
    /**
     * Writes data into the clipboard
     * @param { WriteRequestType } writeObj This object is described in the WriteRequestType typedef
     * @return {Promise.<void>}
     * @tutorial Clipboard.write
    */
    write(writeObj: WriteAnyRequestType): Promise<void>;
    /**
     * Reads available formats for the clipboard type
     * @param { string } type Clipboard Type
     * @return {Promise.Array.<string>}
     * @tutorial Clipboard.getAvailableFormats
    */
    getAvailableFormats(type?: string): Promise<Array<string>>;
}
